==> vue-table-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@xmweb-ui/vue-renderless/table/vue";
import { defineComponent, props, setup as _setup } from "@xmweb-ui/vue-common";
import { iconRadioselected, iconRadio, iconCheck, iconCheckedSur, iconHalfselect } from "@xmweb-ui/vue-icon";
import "@xmweb-ui/vue-theme-mobile/table/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconRadioselected: iconRadioselected(),
    IconRadio: iconRadio(),
    IconCheck: iconCheck(),
    IconCheckedSur: iconCheckedSur(),
    IconHalfselect: iconHalfselect()
  },
  props: [].concat(props, ["columns", "data", "width", "defaultChecked", "keys"]),
  methods: {
    getLeft: function getLeft(index) {
      var left = 0;
      for (var i = 0; i < index; i++) {
        left += this.columns[i].width;
      }
      return left + "px";
    },
    isLastFixed: function isLastFixed(index, item) {
      if (!item.fixed) {
        return false;
      }
      if (index === this.columns.length - 1) {
        return true;
      }
      return !this.columns[index + 1].fixed;
    }
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "xm-mobile-table simple",
    style: {
      width: _vm.width
    }
  }, [_c("table", {
    attrs: {
      "width": _vm.width
    }
  }, [_c("colgroup", _vm._l(_vm.columns, function(col, rowIndex) {
    return _c("col", {
      key: rowIndex,
      attrs: {
        "width": col.width
      }
    });
  }), 0), _c("thead", {
    staticClass: "xm-mobile-table-header"
  }, [_c("tr", _vm._l(_vm.columns, function(col, colIndex) {
    return _c("th", {
      key: colIndex,
      class: {
        overflow: col.showOverflow,
        fixed: col.fixed
      },
      style: {
        left: _vm.getLeft(colIndex)
      }
    }, [_c("div", {
      staticClass: "xm-mobile-table-cell"
    }, [col.type === "selection" ? _c("icon-" + _vm.state.selectCls, {
      tag: "component",
      class: ["xm-mobile-svg-size", {
        "is-check": _vm.state.selectCls !== "check"
      }],
      on: {
        "click": _vm.togeSelectAll
      }
    }) : _vm._e(), !col.type ? _c("div", [_vm._v(" " + _vm._s(col.title) + " ")]) : _vm._e(), _vm.isLastFixed(colIndex, col) ? _c("div", {
      staticClass: "shadow"
    }) : _vm._e()], 1)]);
  }), 0)]), _c("tbody", [_vm._l(_vm.data, function(row, rowIndex) {
    return _c("tr", {
      key: rowIndex,
      class: ["handlerCls", _vm.state.selectedKeys.indexOf(row[_vm.keys]) > -1 ? "" : "is-disabled"]
    }, _vm._l(_vm.columns, function(col, colIndex) {
      return _c("td", {
        key: colIndex,
        class: {
          fixed: col.fixed
        },
        style: {
          left: _vm.getLeft(colIndex)
        }
      }, [_c("div", {
        class: ["xm-mobile-table-cell", {
          overflow: col.showOverflow
        }],
        attrs: {
          "title": col.showOverflow ? row[col.field] : ""
        }
      }, [col.type === "index" ? _c("div", [_vm._v(" " + _vm._s(rowIndex + 1) + " ")]) : col.type === "radio" ? _c(_vm.state.selectedRow === row ? "icon-radioselected" : "icon-radio", {
        tag: "component",
        staticClass: "xm-mobile-svg-size",
        on: {
          "click": function click($event) {
            return _vm.selectRow(row);
          }
        }
      }) : col.type === "selection" ? _c(_vm.state.selected.indexOf(row) === -1 ? "icon-check" : "icon-checked-sur", {
        tag: "component",
        class: ["xm-mobile-svg-size", {
          "is-check": _vm.state.selected.indexOf(row) > -1
        }, {
          "is-disabled": _vm.state.selectedKeys.indexOf(_vm.keys) > -1
        }],
        on: {
          "click": function click($event) {
            return _vm.togeSelected(row);
          }
        }
      }) : _c("div", [_vm._v(" " + _vm._s(row[col.field]) + " ")]), _vm.isLastFixed(colIndex, col) ? _c("div", {
        staticClass: "shadow"
      }) : _vm._e()], 1)]);
    }), 0);
  }), _vm.data && _vm.data.length === 0 ? _c("p", {
    staticClass: "noData"
  }, [_vm._v(" " + _vm._s(_vm.t("ui.transfer.noData")) + " ")]) : _vm._e()], 2)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-table-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/table/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconRadioselected, iconRadio, iconCheck, iconCheckedSur, iconHalfselect } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme-mobile/table/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconRadioselected: iconRadioselected(),
    IconRadio: iconRadio(),
    IconCheck: iconCheck(),
    IconCheckedSur: iconCheckedSur(),
    IconHalfselect: iconHalfselect()
  },
  props: [].concat(props, ["columns", "data", "width", "defaultChecked", "keys"]),
  methods: {
    getLeft: function getLeft(index) {
      var left = 0;
      for (var i = 0; i < index; i++) {
        left += this.columns[i].width;
      }
      return left + "px";
    },
    isLastFixed: function isLastFixed(index, item) {
      if (!item.fixed) {
        return false;
      }
      if (index === this.columns.length - 1) {
        return true;
      }
      return !this.columns[index + 1].fixed;
    }
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-table simple",
    style: {
      width: _vm.width
    }
  }, [_c("table", {
    attrs: {
      "width": _vm.width
    }
  }, [_c("colgroup", _vm._l(_vm.columns, function(col, rowIndex) {
    return _c("col", {
      key: rowIndex,
      attrs: {
        "width": col.width
      }
    });
  }), 0), _c("thead", {
    staticClass: "tiny-mobile-table-header"
  }, [_c("tr", _vm._l(_vm.columns, function(col, colIndex) {
    return _c("th", {
      key: colIndex,
      class: {
        overflow: col.showOverflow,
        fixed: col.fixed
      },
      style: {
        left: _vm.getLeft(colIndex)
      }
    }, [_c("div", {
      staticClass: "tiny-mobile-table-cell"
    }, [col.type === "selection" ? _c("icon-" + _vm.state.selectCls, {
      tag: "component",
      class: ["tiny-mobile-svg-size", {
        "is-check": _vm.state.selectCls !== "check"
      }],
      on: {
        "click": _vm.togeSelectAll
      }
    }) : _vm._e(), !col.type ? _c("div", [_vm._v(" " + _vm._s(col.title) + " ")]) : _vm._e(), _vm.isLastFixed(colIndex, col) ? _c("div", {
      staticClass: "shadow"
    }) : _vm._e()], 1)]);
  }), 0)]), _c("tbody", [_vm._l(_vm.data, function(row, rowIndex) {
    return _c("tr", {
      key: rowIndex,
      class: ["handlerCls", _vm.state.selectedKeys.indexOf(row[_vm.keys]) > -1 ? "" : "is-disabled"]
    }, _vm._l(_vm.columns, function(col, colIndex) {
      return _c("td", {
        key: colIndex,
        class: {
          fixed: col.fixed
        },
        style: {
          left: _vm.getLeft(colIndex)
        }
      }, [_c("div", {
        class: ["tiny-mobile-table-cell", {
          overflow: col.showOverflow
        }],
        attrs: {
          "title": col.showOverflow ? row[col.field] : ""
        }
      }, [col.type === "index" ? _c("div", [_vm._v(" " + _vm._s(rowIndex + 1) + " ")]) : col.type === "radio" ? _c(_vm.state.selectedRow === row ? "icon-radioselected" : "icon-radio", {
        tag: "component",
        staticClass: "tiny-mobile-svg-size",
        on: {
          "click": function click($event) {
            return _vm.selectRow(row);
          }
        }
      }) : col.type === "selection" ? _c(_vm.state.selected.indexOf(row) === -1 ? "icon-check" : "icon-checked-sur", {
        tag: "component",
        class: ["tiny-mobile-svg-size", {
          "is-check": _vm.state.selected.indexOf(row) > -1
        }, {
          "is-disabled": _vm.state.selectedKeys.indexOf(_vm.keys) > -1
        }],
        on: {
          "click": function click($event) {
            return _vm.togeSelected(row);
          }
        }
      }) : _c("div", [_vm._v(" " + _vm._s(row[col.field]) + " ")]), _vm.isLastFixed(colIndex, col) ? _c("div", {
        staticClass: "shadow"
      }) : _vm._e()], 1)]);
    }), 0);
  }), _vm.data && _vm.data.length === 0 ? _c("p", {
    staticClass: "noData"
  }, [_vm._v(" " + _vm._s(_vm.t("ui.transfer.noData")) + " ")]) : _vm._e()], 2)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
